@@ -32,12 +32,16 @@ function(x,
   if (ncol < 1) {
     stop(sQuote("ncol"), " must be greater than 0!", call. = FALSE)
   }
-  
-  Zp <- as.numeric(levels(x@Zp))[x@Zp]
-  Zt <- as.numeric(levels(x@Zt))[x@Zt]    
 
   d <- ncol(x@Dataset)
-
+  
+  Zp <- as.numeric(levels(x@Zp))[x@Zp]
+  Zt <- as.numeric(levels(x@Zt))[x@Zt]
+  
+  zlim <- c(0, max(1, max(Zp) - 1)); zmax <- zlim[2]   
+  
+  unique.Zp <- unique(Zp); s <- length(unique.Zp); sort.unique.Zp <- sort(unique.Zp)
+  
   nrow <- max(1, nrow)
   ncol <- max(1, ncol)
 
@@ -60,17 +64,13 @@ function(x,
 
   ey <- as.matrix(x@Dataset); ep <- Zp - 1
   
-  error <- is.error(Zt, Zp)
+  error <- as.integer(Zt != Zp)
   
   ramp <- colorRamp(colors = c("magenta", "blue", "cyan", "green", "yellow", "red"),
     space = "rgb",
     interpolate = "linear")
     
-  unique.Zp <- unique(Zp); s <- length(unique.Zp); sort.unique.Zp <- sort(unique.Zp)     
-  
-  zlim <- c(0, max(1, s - 1)); zmax <- zlim[2]    
-    
-  plot.col <- rgb(ramp(ep / zmax), maxColorValue = 255);
+  plot.col <- rgb(ramp(ep / zmax), maxColorValue = 255)
   
   legend.col <- rgb(ramp((sort.unique.Zp - 1) / zmax), maxColorValue = 255)
   
@@ -78,7 +78,7 @@ function(x,
   
   legend.pch <- rep(plot.pch, s)
   
-  which.error <- which(error == 1); which.not.error <- which(error != 1)  
+  which.error <- which(error == 1); which.not.error <- which(error != 1)
   
   if (N > 0) {
     figno <- 0
@@ -109,7 +109,7 @@ function(x,
           ylab = "",
           col = "black",
           lwd = 1,
-          cex = plot.cex * 2,
+          cex = plot.cex,
           pch = 1)          
 
         box(col = fg, lty = "solid", lwd = 1)
@@ -153,7 +153,7 @@ function(x,
           
           plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
           
-         .legendA(s = s, text = legend.text, col = legend.col, pch = legend.pch, error = sum(error) != 0)
+          .legendA(s = s, text = legend.text, col = legend.col, pch = legend.pch, error = sum(error) != 0)
   
           par(mfrow = c(nrow, ncol),
             cex = cex,
@@ -171,20 +171,20 @@ function(x,
           figno <- 0
         }
         
-        opar[[ipar]] <- par(no.readonly = TRUE); ipar <- ipar + 1        
+        opar[[ipar]] <- par(no.readonly = TRUE); ipar <- ipar + 1            
       }
     }
   }
   else {
     plot(x = ey[which.not.error, 1],
-      y = ep[which.not.error] + 1,
+      y = Zp[which.not.error],
       type = "p",
       main = "",
       sub = "",
       xlab = "",
       ylab = "",
       xlim = range(ey[, 1]),
-      ylim = range(ep + 1),      
+      ylim = range(Zp),      
       col = plot.col[which.not.error],
       axes = FALSE,
       lwd = 1,
@@ -192,7 +192,7 @@ function(x,
       pch = plot.pch)
           
     points(x = ey[which.error, 1],
-      y = ep[which.error] + 1,
+      y = Zp[which.error],
       type = "p",
       main = "",
       sub = "",
@@ -200,7 +200,7 @@ function(x,
       ylab = "",
       col = "black",
       lwd = 1,
-      cex = plot.cex * 2,
+      cex = plot.cex,
       pch = 1)       
 
     box(col = fg, lty = "solid", lwd = 1)
@@ -241,7 +241,7 @@ function(x,
           
     plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
           
-    .legendA(s = s, text = legend.text, col = legend.col, pch = legend.pch, error = sum(error) != 0)    
+   .legendA(s = s, text = legend.text, col = legend.col, pch = legend.pch, error = sum(error) != 0)
       
     par(mfrow = c(nrow, ncol),
       cex = cex,
@@ -298,12 +298,16 @@ function(x,
   if (ncol < 1) {
     stop(sQuote("ncol"), " must be greater than 0!", call. = FALSE)
   }
-  
-  Zp <- as.numeric(levels(x@Zp))[x@Zp]
-  Zt <- as.numeric(levels(x@Zt))[x@Zt]  
 
   d <- ncol(x@Dataset)
-
+  
+  Zp <- as.numeric(levels(x@Zp))[x@Zp]
+  Zt <- as.numeric(levels(x@Zt))[x@Zt]
+  
+  zlim <- c(0, max(1, max(Zp) - 1)); zmax <- zlim[2]   
+  
+  unique.Zp <- unique(Zp); s <- length(unique.Zp); sort.unique.Zp <- sort(unique.Zp)
+  
   nrow <- max(1, nrow)
   ncol <- max(1, ncol)
 
@@ -326,17 +330,13 @@ function(x,
 
   ey <- as.matrix(x@Dataset); ep <- Zp - 1
   
-  error <- is.error(Zt, Zp)
+  error <- as.integer(Zt != Zp)
   
   ramp <- colorRamp(colors = c("magenta", "blue", "cyan", "green", "yellow", "red"),
     space = "rgb",
     interpolate = "linear")
     
-  unique.Zp <- unique(Zp); s <- length(unique.Zp); sort.unique.Zp <- sort(unique.Zp)     
-  
-  zlim <- c(0, max(1, s - 1)); zmax <- zlim[2]
-      
-  plot.col <- rgb(ramp(ep / zmax), maxColorValue = 255);
+  plot.col <- rgb(ramp(ep / zmax), maxColorValue = 255)
   
   legend.col <- rgb(ramp((sort.unique.Zp - 1) / zmax), maxColorValue = 255)
   
@@ -344,7 +344,7 @@ function(x,
   
   legend.pch <- rep(plot.pch, s)
   
-  which.error <- which(error == 1); which.not.error <- which(error != 1)  
+  which.error <- which(error == 1); which.not.error <- which(error != 1)
   
   if (N > 0) {
     figno <- 0
@@ -375,7 +375,7 @@ function(x,
           ylab = "",
           col = "black",
           lwd = 1,
-          cex = plot.cex * 2,
+          cex = plot.cex,
           pch = 1)          
 
         box(col = fg, lty = "solid", lwd = 1)
@@ -419,8 +419,7 @@ function(x,
           
           plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
           
-          
-          .legendA(s = s, text = legend.text, col = legend.col, pch = legend.pch, error = sum(error) != 0)          
+          .legendA(s = s, text = legend.text, col = legend.col, pch = legend.pch, error = sum(error) != 0)
   
           par(mfrow = c(nrow, ncol),
             cex = cex,
@@ -444,14 +443,14 @@ function(x,
   }
   else {
     plot(x = ey[which.not.error, 1],
-      y = ep[which.not.error] + 1,
+      y = Zp[which.not.error],
       type = "p",
       main = "",
       sub = "",
       xlab = "",
       ylab = "",
       xlim = range(ey[, 1]),
-      ylim = range(ep + 1),      
+      ylim = range(Zp),      
       col = plot.col[which.not.error],
       axes = FALSE,
       lwd = 1,
@@ -459,7 +458,7 @@ function(x,
       pch = plot.pch)
           
     points(x = ey[which.error, 1],
-      y = ep[which.error] + 1,
+      y = Zp[which.error],
       type = "p",
       main = "",
       sub = "",
@@ -467,7 +466,7 @@ function(x,
       ylab = "",
       col = "black",
       lwd = 1,
-      cex = plot.cex * 2,
+      cex = plot.cex,
       pch = 1)       
 
     box(col = fg, lty = "solid", lwd = 1)
@@ -507,8 +506,8 @@ function(x,
       new = TRUE)
           
     plot(0, 0, type = "n", bty = "n", xaxt = "n", yaxt = "n")
-    
-    .legendA(s = s, text = legend.text, col = legend.col, pch = legend.pch, error = sum(error) != 0)          
+          
+   .legendA(s = s, text = legend.text, col = legend.col, pch = legend.pch, error = sum(error) != 0)
       
     par(mfrow = c(nrow, ncol),
       cex = cex,
@@ -523,7 +522,7 @@ function(x,
       
     par(oma = c(1 + 0.2, 0.2, 0.2, 0.2))
     
-    opar[[ipar]] <- par(no.readonly = TRUE); ipar <- ipar + 1
+    opar[[ipar]] <- par(no.readonly = TRUE); ipar <- ipar + 1        
   }
   
   rm(list = ls()[!(ls() %in% c("opar"))])
